define(
//begin v1.x content
{
	"HKD_displayName": "dòlar de Hong Kong",
	"CNY_displayName": "iuan xinès",
	"JPY_displayName": "ien japonès",
	"JPY_symbol": "¥",
	"USD_displayName": "dòlar dels Estats Units",
	"CAD_symbol": "CAD",
	"GBP_displayName": "lliura esterlina britànica",
	"CHF_displayName": "franc suís",
	"CNY_symbol": "CNY",
	"EUR_displayName": "euro",
	"GBP_symbol": "£",
	"CAD_displayName": "dòlar canadenc",
	"USD_symbol": "USD",
	"EUR_symbol": "€",
	"AUD_displayName": "dòlar australià",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AU$"
}
//end v1.x content
);